@@ -1,11 +1,14 @@
 #' Tidy import tool for EarthExplorer .csv export files
 #' 
-#' Imports CSV files exported from EarthExplorer into data.frames and annotates missing fields 
+#' Imports and tidies CSV files exported from EarthExplorer into data.frames and annotates missing fields.
 #' 
 #' @param x Character, Character or list. One or more paths to EarthExplorer export files.
 #' @return data.frame
 #' @details 
 #' The \href{http://earthexplorer.usgs.gov/}{EarthExplorer} CSV file can be produced from the search results page. Above the results click on 'export results' and select 'comma (,) delimited'.
+#' 
+#' Note that only a subset of columns is imported which was deemed interesting. Please contact the maintainer if you think an omited column should be included. 
+#' 
 #' @export 
 #' @examples 
 #' library(ggplot2)
@@ -25,7 +28,10 @@ readEE <- function(x) {
 	llee <- lapply(x, function(ix){
                 if(!file.exists(ix)) stop(paste0("Can't find file ", ix), call.=FALSE )
 				df <- read.csv(ix, stringsAsFactors = FALSE, quote = "", fileEncoding = "latin1")
-				names(df)[names(df) == "Scene.Cloud.Cover"] <- "Cloud.Cover"
+                namesLut <- c("Scene.Cloud.Cover"="Cloud.Cover", "Acquisition.Date"="Date.Acquired",  "Day.Night.Indicator"="Day.Night")
+				for(i in names(namesLut)) {
+                    names(df)[names(df) == i] <- namesLut[i]
+                }
 				allLScats <- c("Landsat.Scene.Identifier", "WRS.Path", "WRS.Row", "Data.Category", "Cloud.Cover",
 						"Station.Identifier", "Day.Night", "Data.Type.Level.1", "Date.Acquired", 
 						"Sun.Elevation", "Sun.Azimuth", "Geometric.RMSE.Model.X", 
